Learn R Programming

nonprobsampling (version 0.1.0)

build_domains_df: Build the estimates summary data frame

Description

Constructs the `estimates` data frame that is stored in a `pwmean` object. Each row corresponds to one estimate. The 95 computed using the 0.975 normal quantile (approximately 1.96).

Usage

build_domains_df(labels, mean_unw, se_unw, mean_adj, se_adj)

Value

A data frame with one row per domain and columns `domain`, `unweighted_mean`, `unweighted_se`, `unweighted_lower`, `unweighted_upper`, `adjusted_mean`, `adjusted_se`, `adjusted_lower`, and `adjusted_upper`.

Arguments

labels

Character vector of domain labels, one entry per domain.

mean_unw

Numeric vector of unweighted (naive) domain means.

se_unw

Numeric vector of standard errors for the unweighted means.

mean_adj

Numeric vector of pseudo-weighted (adjusted) domain means.

se_adj

Numeric vector of standard errors for the adjusted means.