Internal helper to compute $$D = Var_p\left( \sum_{j \in s_p} d_j \pi_j x_j \right)$$ from an existing survey design object created by survey::svydesign() or survey::svrepdesign().
compute_D_CLW(sp_des, pi_sp, Xp)A `p x p` covariance matrix `D`.
A survey design object of class `"survey.design2"` or `"svyrep.design"`.
Numeric vector of estimated values multiplying `X_p` in the CLW estimating equation. Length must equal the number of rows in `sp_des$variables`.
Numeric matrix of dimension `n_p x p`. Each row is the covariate vector `x_j` used in the CLW estimating equation.
In the CLW method, the probability sample contribution in the estimating equation is \(\pi_j d_j x_j\), where `pi_j` corresponds to the inverse of the estimated pseudo-weight. Thus the design-based covariance matrix is obtained by treating \(h_j = \pi_j x_j\) as the survey total variable.