Learn R Programming

nonprobsampling (version 0.1.0)

dispatch_estimator_one_domain: Run the estimator for a single domain

Description

Selects and calls the specific estimator function based on `build$method`, passing the relevant matrices and vectors for one domain at a time.

Usage

dispatch_estimator_one_domain(build, Y, zvec, w, X)

Value

A list with components `mean` and `variance`.

Arguments

build

A `pw_fit` object returned by the build step.

Y

Outcome vector of length `n`.

zvec

Domain indicator vector of length `n`.

w

Pseudo-weight vector of length `n`.

X

Design matrix for the convenience sample, with dimension `n x p`.