Learn R Programming

nonprobsampling (version 0.1.0)

precal_cumulative_order: Cumulative precalibration across multiple probability samples

Description

Performs a cumulative precalibration across multiple probability samples by sequentially calibrating each sample's weights to align with the marginal totals of the previous samples. Called internally by est_pw().

Usage

precal_cumulative_order(sp_raw, sp_new, weight, sp_order)

Value

A list with components sp_new, total_vector,

log_messages, and order_used.

Arguments

sp_raw

A list of data frames (raw reference samples).

sp_new

A list of data frames (working reference samples) with the same structure as sp_raw. Calibrated weights are written back in place.

weight

A list of weight column name strings, one per sample.

sp_order

"size" to process largest sample first; otherwise the original list order is used.