Constructs the `estimates` data frame that is stored in a `pwmean` object. Each row corresponds to one estimate. The 95 computed using the 0.975 normal quantile (approximately 1.96).
build_domains_df(labels, mean_unw, se_unw, mean_adj, se_adj)A data frame with one row per domain and columns `domain`, `unweighted_mean`, `unweighted_se`, `unweighted_lower`, `unweighted_upper`, `adjusted_mean`, `adjusted_se`, `adjusted_lower`, and `adjusted_upper`.
Character vector of domain labels, one entry per domain.
Numeric vector of unweighted (naive) domain means.
Numeric vector of standard errors for the unweighted means.
Numeric vector of pseudo-weighted (adjusted) domain means.
Numeric vector of standard errors for the adjusted means.