Internal helper to compute $$D = Var_p\left( \sum_{j \in s_p} d_j x_j \right)$$ from an existing survey design object created by survey::svydesign() or survey::svrepdesign().
compute_D_raking(sp_des, Xp)A `p x p` covariance matrix `D`.
A survey design object of class `"survey.design2"` or `"svyrep.design"`.
Numeric matrix of dimension `n_p x p`. Each row is the covariate vector `x_j` used in the calibration estimating equation.
In the raking ratio calibration method, the probability sample contribution in the estimating equation is \(d_j x_j\), so the design-based covariance matrix is obtained by treating \(h_j = x_j\) as the survey total variable.