Selects and calls the specific estimator function based on `build$method`, passing the relevant matrices and vectors for one domain at a time.
dispatch_estimator_one_domain(build, Y, zvec, w, X)A list with components `mean` and `variance`.
A `pw_fit` object returned by the build step.
Outcome vector of length `n`.
Domain indicator vector of length `n`.
Pseudo-weight vector of length `n`.
Design matrix for the convenience sample, with dimension `n x p`.