Prints a formatted table showing the original row count, rows used, and rows excluded due to missing participation model variables, for each dataset (`sc` and each reference survey).
Usage
# S3 method for class 'pw_na_summary'
print(x, ...)Prints a formatted table showing the original row count, rows used, and rows excluded due to missing participation model variables, for each dataset (`sc` and each reference survey).
# S3 method for class 'pw_na_summary'
print(x, ...)