Skip to contents

This dataset represents a probability sample derived from the 1999–2010 cycles of the National Health and Nutrition Examination Survey (NHANES). It is used as a probability reference survey to support the pseudo-weighting methods implemented in the nonprobsampling package.

Usage

data(sp1)

Format

A data frame with 3494 observations and 14 variables:

agecat

Age category (factor with 4 levels: 1 = 55–59, 2 = 60–64, 3 = 65–69, 4 = 70+)

marital

Marital status (factor with 4 levels: 1 = Married Or Living As Married, 2 = Widowed, 3 = Divorced or Separated, 4 = Never Married)

race

Race category (factor with 4 levels: 1 = White, 2 = Black, 3 = Hispanic, 4 = Other)

education

Education level (factor with 5 levels: 1 = Less Than 8 Years, 2 = 8–11 Years, 3 = 12 Years Or Completed High School, 4 = College Graduate, 5 = Postgraduate)

employment

Employment status (factor with 2 levels: 0 = Not Working, 1 = Working)

smoking

Smoking status (factor with 3 levels: 1 = Never Smoker, 2 = Former Smoker, 3 = Current Smoker)

comorbidity

General comorbidity indicator (factor with 2 levels: 0 = No, 1 = Yes)

psa_level

Serum prostate-specific antigen level (numeric)

BMI

Body mass index category (factor with 4 levels: "Normal", "Overweight", "Obese", "Morbidly Obese")

diabetes

Diabetes diagnosis indicator (factor with 2 levels: 0 = No, 1 = Yes)

pros_enlarged

Prostate enlargement indicator (factor with 2 levels: 0 = No, 1 = Yes)

strata_sp1

Stratum identifier for complex survey design (numeric)

psu_sp1

Primary sampling unit identifier for complex survey design (numeric)

wts_sp1

10-year interview sampling weights (numeric)

Derived from the National Health and Nutrition Examination Survey (NHANES), 1999–2010 cycles, conducted by the U.S. National Center for Health Statistics (NCHS).

Details

The dataset includes auxiliary variables shared with the nonprobability sample sc, enabling the construction of pseudo-weights to adjust for participation bias. Survey design variables and sampling weights are provided to support design-consistent estimation.

The sp1 dataset contains the outcome variable psa_level, which is also observed in sc, allowing for the evaluation of pseudo-weighted estimators against estimates based on true sampling weights. It may also be incorporated into the participation model, potentially enhancing bias reduction when participation depends on the outcome.

Examples

data(sp1)
str(sp1)
#> 'data.frame':	3494 obs. of  14 variables:
#>  $ agecat       : Factor w/ 4 levels "1","2","3","4": 4 2 4 3 2 2 1 1 4 3 ...
#>  $ marital      : Factor w/ 4 levels "1","2","3","4": 1 3 1 1 1 1 1 1 1 1 ...
#>  $ race         : Factor w/ 4 levels "1","2","3","4": 3 1 3 3 1 1 1 1 1 1 ...
#>  $ education    : Factor w/ 5 levels "1","2","3","4",..: 1 3 2 3 3 2 2 4 5 2 ...
#>  $ employment   : Factor w/ 2 levels "0","1": 1 1 1 1 1 1 2 2 1 1 ...
#>  $ smoking      : Factor w/ 3 levels "1","2","3": 2 2 2 2 2 2 2 1 3 2 ...
#>  $ comorbidity  : Factor w/ 2 levels "0","1": 2 2 1 2 2 1 2 1 2 1 ...
#>  $ psa_level    : num  NA NA NA NA NA NA NA NA NA NA ...
#>  $ BMI          : Factor w/ 4 levels "Morbidly Obese",..: 2 3 4 3 4 3 4 4 2 4 ...
#>  $ diabetes     : Factor w/ 2 levels "0","1": 2 2 1 2 1 1 2 1 1 1 ...
#>  $ pros_enlarged: Factor w/ 2 levels "0","1": 2 1 1 2 1 2 1 1 2 1 ...
#>  $ strata_sp1   : int  13 12 6 13 5 12 10 11 1 7 ...
#>  $ psu_sp1      : int  2 2 1 2 2 1 1 1 2 1 ...
#>  $ wts_sp1      : num  401 8923 481 498 9314 ...
summary(sp1)
#>  agecat   marital  race     education employment smoking  comorbidity
#>  1: 697   1:2665   1:1762   1:743     0:2057     1:1097   0:1286     
#>  2:1074   2: 182   2: 747   2:574     1:1437     2:1582   1:2208     
#>  3: 879   3: 469   3: 880   3:742                3: 815              
#>  4: 844   4: 178   4: 105   4:707                                    
#>                             5:728                                    
#>                                                                      
#>                                                                      
#>    psa_level                  BMI       diabetes pros_enlarged   strata_sp1   
#>  Min.   : 0.070   Morbidly Obese: 324   0:2744   0:2699        Min.   : 1.00  
#>  1st Qu.: 0.670   Normal        : 891   1: 750   1: 795        1st Qu.:17.00  
#>  Median : 1.215   Obese         : 748                          Median :36.00  
#>  Mean   : 2.133   Overweight    :1531                          Mean   :36.81  
#>  3rd Qu.: 2.340                                                3rd Qu.:58.00  
#>  Max.   :72.540                                                Max.   :74.00  
#>  NA's   :1190                                                                 
#>     psu_sp1        wts_sp1       
#>  Min.   :1.00   Min.   :  346.4  
#>  1st Qu.:1.00   1st Qu.: 1841.4  
#>  Median :2.00   Median : 4675.0  
#>  Mean   :1.53   Mean   : 5952.2  
#>  3rd Qu.:2.00   3rd Qu.: 9370.5  
#>  Max.   :3.00   Max.   :27094.7  
#>